reporting Package
=================

:mod:`reporting` Package
------------------------

.. automodule:: stoqlib.reporting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`boleto` Module
--------------------

.. automodule:: stoqlib.reporting.boleto
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`booklet` Module
---------------------

.. automodule:: stoqlib.reporting.booklet
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`callsreport` Module
-------------------------

.. automodule:: stoqlib.reporting.callsreport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`clientcredit` Module
-------------------------

.. automodule:: stoqlib.reporting.clientcredit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`financial` Module
-----------------------

.. automodule:: stoqlib.reporting.financial
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`inventory` Module
-----------------------

.. automodule:: stoqlib.reporting.inventory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`labelreport` Module
-------------------------

.. automodule:: stoqlib.reporting.labelreport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loanreceipt` Module
-------------------------

.. automodule:: stoqlib.reporting.loanreceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`payment` Module
---------------------

.. automodule:: stoqlib.reporting.payment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paymentsreceipt` Module
-----------------------------

.. automodule:: stoqlib.reporting.paymentsreceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`product` Module
---------------------

.. automodule:: stoqlib.reporting.product
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`production` Module
------------------------

.. automodule:: stoqlib.reporting.production
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchase` Module
----------------------

.. automodule:: stoqlib.reporting.purchase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`purchasereceival` Module
-------------------------------

.. automodule:: stoqlib.reporting.purchasereceival
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`report` Module
--------------------

.. automodule:: stoqlib.reporting.report
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sale` Module
------------------

.. automodule:: stoqlib.reporting.sale
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salereturn` Module
-------------------------

.. automodule:: stoqlib.reporting.salereturn
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`service` Module
---------------------

.. automodule:: stoqlib.reporting.service
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stockdecreasereceipt` Module
----------------------------------

.. automodule:: stoqlib.reporting.stockdecreasereceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`till` Module
------------------

.. automodule:: stoqlib.reporting.till
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transferreceipt` Module
------------------------------

.. automodule:: stoqlib.reporting.transferreceipt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: stoqlib.reporting.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`workorder` Module
-----------------------

.. automodule:: stoqlib.reporting.workorder
    :members:
    :undoc-members:
    :show-inheritance:
